@@ -1,8 +1,6 @@
 package Data::Walk::Extracted::Types;
-BEGIN {
-  $Data::Walk::Extracted::Types::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = qv("v0.26.8");
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = version->declare('v0.26.14');
 use strict;
 use warnings;
 use Type::Utils -all;
@@ -37,7 +35,7 @@ __END__
 Data::Walk::Extracted::Types - A type library for Data::Walk::Extracted
 
 =head1 SYNOPSIS
-    
+
     package Data::Walk::Extracted::MyRole;
 	use Moose::Role;
 	use Data::Walk::Extracted::Types qw(
@@ -46,11 +44,11 @@ Data::Walk::Extracted::Types - A type library for Data::Walk::Extracted
     use Log::Shiras::Types qw(
         posInt #See Code for other options
     );
-    
+
     has 'someattribute' =>(
             isa     => posInt,#Note the lack of quotes
         );
-    
+
     sub valuetestmethod{
         my ( $self, $value ) = @_;
         return is_posInt( $value );
@@ -63,15 +61,15 @@ Data::Walk::Extracted::Types - A type library for Data::Walk::Extracted
 =head1 DESCRIPTION
 
 This is the custom type class that ships with the L<Data::Walk::Extracted
-|https://metacpan.org/module/Data::Walk::Extracted> package.  Wherever 
-possible errors to coersions are passed back to the type so coersion failure 
+|https://metacpan.org/module/Data::Walk::Extracted> package.  Wherever
+possible errors to coersions are passed back to the type so coersion failure
 will be explained.
 
-There are only subtypes in this package!  B<WARNING> These types should be 
-considered in a beta state.  Future type fixing will be done with a set of tests in 
+There are only subtypes in this package!  B<WARNING> These types should be
+considered in a beta state.  Future type fixing will be done with a set of tests in
 the test suit of this package.  (currently none are implemented)
 
-See L<MooseX::Types|https://metacpan.org/module/MooseX::Types> for general re-use 
+See L<MooseX::Types|https://metacpan.org/module/MooseX::Types> for general re-use
 of this module.
 
 =head1 Types
@@ -104,7 +102,7 @@ L<github Data-Walk-Extracted/issues|https://github.com/jandrew/Data-Walk-Extract
 
 =over
 
-Jed Lund 
+Jed Lund
 
 jandrew@cpan.com
 
@@ -140,4 +138,4 @@ L<MooseX::Types::Perl|https://metacpan.org/module/MooseX::Types::Perl>
 
 =cut
 
-#########1 Main POD ends      3#########4#########5#########6#########7#########8#########9
\ No newline at end of file
+#########1 Main POD ends      3#########4#########5#########6#########7#########8#########9
