@@ -2,8 +2,8 @@
 use YAML::Any;
 use Moose::Util qw( with_traits );
 use lib '../lib';
-use Data::Walk::Extracted 0.024;
-use Data::Walk::Print 0.024;
+use Data::Walk::Extracted;
+use Data::Walk::Print;
 
 #Use YAML to compress writing the data ref
 my  $firstref = Load(
